@@ -38,7 +38,7 @@ class Postgres_Handler:
                 except psycopg2.ProgrammingError as ex:
                     #if ex == "no results to fetch":
                     status = 2
-                    results = "Success"
+                    results = f"{ex}"
                 except Exception as ex:
                     status = -1
                     results = f"{ex}"
@@ -215,10 +215,10 @@ class Postgres_Handler:
             for key, value in kwargs.items():
                 if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
                 
-                clause_section += f' "{key}" = %({key})s AND'
+                clause_section += f' "{key}"=%({key})s,'
                 values_dict[key] = value
             
-            query_string += clause_section[:-4]
+            query_string += clause_section[:-1]
 
             if id_key not in kwargs: assert("Error: ID of record required for an update!")
             
